@@ -15,6 +15,7 @@ from sqlalchemy import (
     Boolean,
     Column,
     DateTime,
+    Float,
     ForeignKey,
     Integer,
     String,
@@ -122,10 +123,13 @@ class Team(Base):
             .join(UserTeam)
             .join(UserPoints)
             .join(Team)
+            .filter(Team.guild_xid == guild_xid)
             .group_by(Team.name)
             .all()
         )
-        results = {}
+        server = session.query(Server).filter(Server.guild_xid == guild_xid).one_or_none()
+        assert server
+        results = {team.name: 0 for team in server.teams}
         for row in rows:
             results[row[0]] = row[1]
         return results
@@ -296,6 +300,7 @@ class Game(Base):
     system = Column(
         String(30), nullable=False, server_default=text("'spelltable'"), index=True
     )
+    game_power = Column(Float, nullable=True)
     users = relationship("User", back_populates="game", uselist=True)
     tags = relationship("Tag", secondary=games_tags, back_populates="games", uselist=True)
     server = relationship("Server", back_populates="games")
@@ -337,6 +342,10 @@ class Game(Base):
         ]
         if power:
             having_filters.append(between(func.avg(User.power), power - 1, power + 1))
+            if power >= 7:
+                having_filters.append(func.avg(User.power) >= 7)
+            else:
+                having_filters.append(func.avg(User.power) < 7)
         else:
             select_filters.append(User.power == None)
         inner = (
